//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
//
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Fragment, useEffect, useState } from "react";
import { isNumber, cloneDeep } from "lodash";
import SVG from "./svg";
import Img from "./img";
import GradientDiv from "./gradient-div";
import { isNonEmptyString, COLORS, stringToColor, getRecordDisplay } from "primeobjects-helper-util";
import { Menu, Transition } from "@headlessui/react";
import { map, round } from "lodash";
var styles = {
    count: { fontSize: 8, color: COLORS.WHITE, alignSelf: "center" }
};
export var Avatar = function (props) {
    var countStyle = props.countStyle, hide = props.hide, count = props.count, menuItems = props.menuItems, nameStyle = props.nameStyle, svgStyle = props.svgStyle, colorFromName = props.colorFromName, imgStyle = props.imgStyle, menuPosition = props.menuPosition, showName = props.showName;
    var wrapperClassName = props.wrapperClassName ? props.wrapperClassName : "";
    var wrapperStyle = props.wrapperStyle ? props.wrapperStyle : {};
    var userClassName = props.userClassName ? props.userClassName : "";
    var userStyle = props.userStyle ? props.userStyle : {};
    var _a = useState({}), data = _a[0], setData = _a[1];
    var backgroundColor = isNonEmptyString(props.backgroundColor) ? props.backgroundColor : COLORS.WHITE;
    var borderColor = isNonEmptyString(props.borderColor) ? props.borderColor : COLORS.BLACK;
    var color = isNonEmptyString(props.color) ? props.color : borderColor;
    var display = getRecordDisplay(data);
    var nameClass = props.nameClass ? props.nameClass : "";
    var imgClass = props.imgClass ? props.imgClass : "";
    var countWrapperStyle = props.countWrapperStyle ? props.countWrapperStyle : {};
    if (colorFromName) {
        backgroundColor = stringToColor(display);
        borderColor = backgroundColor;
        color = COLORS.WHITE;
    }
    useEffect(function () {
        setData(props.data ? cloneDeep(props.data) : {});
    }, [props.data]);
    var size = props.size ? props.size : 38;
    var firstName = data.firstName, lastName = data.lastName, avatar = data.avatar, currentStatus = data.currentStatus;
    if (!isNonEmptyString(firstName) && !isNonEmptyString(firstName)) {
        firstName = display.split(" ")[0];
        if (display.split(" ").length > 1)
            lastName = display.split(" ")[1];
    }
    var onClick = function () {
        props.onClick && props.onClick(data);
    };
    var renderName = function () {
        if (!showName)
            return null;
        return (React.createElement(GradientDiv, { tooltip: display, className: "flex-1 font-medium text-base whitespace-nowrap flex flex-row items-center over", style: { height: size, marginLeft: size / 3, width: "calc(100% - ".concat(round(size / 3, 0), "px)") }, gradientAreaWidth: props.nameGradientAreaWidth, gradientStages: props.nameGradientStages, gradientColorRGB: props.nameGradientColorRGB, onChangeOverflow: props.nameOnChangeOverflow }, display));
    };
    var renderAvatar = function () {
        return isNonEmptyString(avatar) ? (React.createElement(Img, { className: "rounded-full border border-gray-20 ".concat(imgClass), src: avatar, alt: "", style: __assign({ width: size }, imgStyle) })) : isNonEmptyString(firstName) || isNonEmptyString(firstName) ? (React.createElement("div", { className: "flex flex-row items-center rounded-full border ".concat(nameClass), style: __assign({ minWidth: size, minHeight: size, borderColor: borderColor, backgroundColor: backgroundColor }, nameStyle) },
            React.createElement("div", { className: "flex flex-row justify-center w-full" },
                React.createElement("span", { style: { color: color } }, isNonEmptyString(firstName) ? firstName.substring(0, 1).toUpperCase() : ""),
                React.createElement("span", { style: { color: color } }, isNonEmptyString(lastName) ? lastName.substring(0, 1).toUpperCase() : "")))) : (React.createElement(SVG, { id: "page-header-me", size: size, style: svgStyle, color: color, src: "/icons/platform/circle-user.svg" }));
    };
    var renderUser = function () {
        return menuItems && menuItems.length > 0 ? (React.createElement(Menu, { as: "div", className: "relative inline-block text-left w-full cursor-pointer ".concat(userClassName), style: userStyle },
            React.createElement(Menu.Button, { className: "flex text-sm w-full", style: { minWidth: size, minHeight: size } },
                renderAvatar(),
                renderName()),
            isNonEmptyString(currentStatus) && (React.createElement("div", { className: "absolute right-0 top-0 rounded-full ".concat(currentStatus == "on" ? "bg-green-600" : "bg-red-600"), style: { width: 10, height: 10 } })),
            React.createElement(Transition, { as: Fragment, enter: "transition ease-out duration-100", enterFrom: "transform opacity-0 scale-95", enterTo: "transform opacity-100 scale-100", leave: "transition ease-in duration-75", leaveFrom: "transform opacity-100 scale-100", leaveTo: "transform opacity-0 scale-95" },
                React.createElement(Menu.Items, { className: "origin-top-right absolute z-50 ".concat(menuPosition == "right" ? "right-0" : "left-0", " mt-2 w-48 rounded-md shadow-lg bg-white ring-1 ring-black ring-opacity-5 focus:outline-none") },
                    React.createElement("div", { className: "py-1" }, map(menuItems, function (item, index) {
                        return (React.createElement(Menu.Item, { key: "".concat(item.title, "-").concat(index) }, function (_a) {
                            var active = _a.active;
                            return (React.createElement("div", { onClick: item.onClick, className: "".concat(active ? "bg-gray-100" : "", " cursor-pointer block px-4 py-1 text-base text-gray-800") }, item.title));
                        }));
                    })))))) : (React.createElement("div", { className: "relative inline-block text-left w-full ".concat(props.onClick ? "cursor-pointer" : "", " ").concat(userClassName), style: userStyle, onClick: onClick },
            React.createElement("div", { className: "flex text-sm w-full", style: { minWidth: size, minHeight: size } },
                renderAvatar(),
                renderName())));
    };
    return hide ? null : (React.createElement(React.Fragment, null,
        React.createElement("div", { className: "avatar ".concat(isNonEmptyString(wrapperClassName) ? wrapperClassName : ""), style: __assign({ height: size, position: "relative" }, wrapperStyle) },
            renderUser(),
            isNumber(count) && count > 0 && (React.createElement("div", { className: "flex flex-row justify-center w-full", style: __assign({ width: size / 2, height: size / 2, position: "absolute", top: -5, right: -5, borderRadius: 9, backgroundColor: COLORS.RED["800"], justifyContent: "space-around" }, countWrapperStyle) },
                React.createElement("div", { style: __assign(__assign({}, styles.count), countStyle) }, count > 9 ? "9+" : count))))));
};
export default Avatar;
//# sourceMappingURL=avatar.js.map