//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
//
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
import React, { useEffect, useState } from "react";
import { isInteger, isNil } from "lodash";
import { useResizeDetector } from "react-resize-detector";
export var GradientDiv = function (props) {
    var children = props.children, tooltip = props.tooltip, style = props.style;
    var _a = useResizeDetector(), width = _a.width, height = _a.height, ref = _a.ref;
    var _b = useState(false), isOverflowX = _b[0], setIsOverflowX = _b[1];
    var className = props.className ? props.className : "";
    var alignment = props.alignment == "right" ? "right" : "left";
    var gradientAreaWidth = !isNil(props.gradientAreaWidth) && isInteger(props.gradientAreaWidth) && props.gradientAreaWidth > 20 ? props.gradientAreaWidth : !isNil(width) ? width : "20%";
    var gradientStages = props.gradientStages ? props.gradientStages : [65, 75, 85];
    var rgb = props.gradientColorRGB ? props.gradientColorRGB : { r: 255, g: 255, b: 255 };
    useEffect(function () {
        var overflow = ref.current.scrollWidth - ref.current.clientWidth > 0;
        if (isOverflowX != overflow && props.onChangeOverflow)
            props.onChangeOverflow(overflow);
        setIsOverflowX(overflow);
    }, [width, children]);
    return (React.createElement("div", { ref: ref, style: style, title: isOverflowX && tooltip ? tooltip : "", className: "gradient-div w-full relative whitespace-nowrap overflow-hidden grid ".concat(alignment == "right" && !isOverflowX ? "text-right" : "text-left", " ").concat(className) },
        children,
        isOverflowX && (React.createElement("div", { className: "absolute gradient-div-tail", style: {
                height: height,
                top: 0,
                right: 0,
                width: gradientAreaWidth,
                background: "linear-gradient(90deg, rgba(".concat(rgb.r, ",").concat(rgb.g, ",").concat(rgb.b, ",0) 0%, rgba(").concat(rgb.r, ",").concat(rgb.g, ",").concat(rgb.b, ",0.25) ").concat(gradientStages[0], "%, rgba(").concat(rgb.r, ",").concat(rgb.g, ",").concat(rgb.b, ",0.5) ").concat(gradientStages[1], "%, rgba(").concat(rgb.r, ",").concat(rgb.g, ",").concat(rgb.b, ",0.75) ").concat(gradientStages[2], "%, rgb(").concat(rgb.r, ",").concat(rgb.g, ",").concat(rgb.b, "))")
            } }))));
};
export default GradientDiv;
//# sourceMappingURL=gradient-div.js.map